@@ -27,13 +27,17 @@
 #define  Y_CPUSTATES	2
 #define  X_MEM		8
 #define  Y_MEM		3
+#define  X_DB		0
+#define  Y_DB		4
+#define  X_IO		0
+#define  Y_IO		5
 #define  X_SWAP		6
-#define  Y_SWAP		4
-#define  Y_MESSAGE	4
+#define  Y_SWAP		6
+#define  Y_MESSAGE	6
 #define  X_HEADER	0
-#define  Y_HEADER	5
+#define  Y_HEADER	7
 #define  X_IDLECURSOR	0
-#define  Y_IDLECURSOR	4
-#define  Y_PROCS	6
+#define  Y_IDLECURSOR	6
+#define  Y_PROCS	8
 
 #endif							/* _LAYOUT_H_ */
