@@ -828,3 +828,10 @@ int			pid;
 
 	return (-1);
 }
+
+void
+get_io_info(struct io_info *io_info)
+{
+	/* Not supported yet */
+	memset(io_info, 0, sizeof(*io_info));
+}
