@@ -759,8 +759,10 @@ read_one_proc_stat(struct top_proc *proc, struct process_select *sel)
 	buffer[len] = '\0';
 	p = buffer;
 
-	p = skip_token(p);			/* rchar */
-	p = skip_token(p);			/* wchar */
+	p = skip_token(p);			/* rchar label */
+	p = skip_token(p);			/* rchar value */
+	p = skip_token(p);			/* wchar label */
+	p = skip_token(p);			/* wchar value */
 
 	GET_VALUE(tmp);				/* syscr */
 	proc->syscr[proc->index] = tmp;
@@ -775,9 +777,6 @@ read_one_proc_stat(struct top_proc *proc, struct process_select *sel)
 
 	GET_VALUE(tmp);				/* write_bytes */
 	proc->write_bytes[proc->index] = tmp;
-
-	GET_VALUE(tmp);				/* cancelled_write_bytes */
-	proc->write_bytes[proc->index] -= tmp;
 }
 
 caddr_t
