@@ -11,8 +11,7 @@
 #include <sys/tree.h>
 #endif /* __FreeBSD__*/
 #ifdef __linux__
-#include <bsd/stdlib.h>
-#include <bsd/sys/tree.h>
+#include "tree.h"
 #endif							/* __linux__ */
 #include <string.h>
 #include <sys/time.h>
@@ -209,7 +208,7 @@ static char *swapnames[NSWAPSTATS + 1] =
 };
 
 static char fmt_header[] =
-"      PID X           SIZE   RES STATE   XTIME  QTIME  %CPU LOCKS COMMAND";
+"    PID X           SIZE   RES STATE   XTIME  QTIME  %CPU LOCKS COMMAND";
 
 char		fmt_header_io_r[] =
 "    PID RCHAR WCHAR   SYSCR   SYSCW READS WRITES CWRITES COMMAND";
@@ -714,7 +713,7 @@ format_next_process_r(caddr_t handler)
 	struct top_proc_r *p = &pgrtable[proc_r_index++];
 
 	snprintf(fmt, sizeof(fmt),
-			 "%7d %-8.8s %5s %5s %-6s %5s %5s %5.1f %5d %s",
+			 "%7d %-10.8s %5s %5s %-6s %5s %5s %5.1f %5d %s",
 			 (int) p->pid,		/* Some OS's need to cast pid_t to int. */
 			 p->usename,
 			 format_k(p->size),
