@@ -864,3 +864,10 @@ compare_time(struct proc **pp1, struct proc **pp2)
 
 	return (result);
 }
+
+void
+get_io_info(struct io_info *io_info)
+{
+	/* Not supported yet */
+	memset(io_info, 0, sizeof(*io_info));
+}
