@@ -749,3 +749,10 @@ struct sysinfo *percpu_si;
 		percpu_p++;
 	}
 }
+
+void
+get_io_info(struct io_info *io_info)
+{
+	/* Not supported yet */
+	memset(io_info, 0, sizeof(*io_info));
+}
